connectivitymodules/SeCon/servers/pcconn/src/sconpcconnserver.cpp
changeset 49 392bf116d9ed
parent 36 9ba7f05d28a5
--- a/connectivitymodules/SeCon/servers/pcconn/src/sconpcconnserver.cpp	Tue Jul 06 14:06:02 2010 +0300
+++ b/connectivitymodules/SeCon/servers/pcconn/src/sconpcconnserver.cpp	Wed Aug 18 09:39:14 2010 +0300
@@ -2310,9 +2310,9 @@
         
         if ( aResult->iApps.Count() > 0 )
             {
-            // 5 * KMaxFileName should be enought
-            // ( 4 items of TFileName and uid + type + size + 6* "#" )
-            HBufC8* buf = HBufC8::NewLC( 5 * KMaxFileName );
+            // 6 * KMaxFileName should be enought
+            // ( 5 items of TFileName and uid + type + size + 7* "#" )
+            HBufC8* buf = HBufC8::NewLC( 6 * KMaxFileName );
             TPtr8 ptrBuf = buf->Des();
             
             aContent->applications = new ( ELeave ) ConML_Applications_t();
@@ -2330,7 +2330,7 @@
                     aResult->iApps[i]->iName));
                 CleanupStack::PopAndDestroy(); // BufToDesLC
                 
                 // create uid: UID # Type # Size # Version # Vendor # Parent app. name #
                 LOGGER_WRITE( "CSConPCConnSession::AppendListInstalledAppsResultsL() : Create Uid" );
                 
                 ptrBuf.Copy( UidToDesLC( aResult->iApps[i]->iUid ) );
@@ -2358,6 +2358,13 @@
                 CleanupStack::PopAndDestroy(); // BufToDesLC
                 
                 ptrBuf.Append( KSConAppInfoSeparator );
+                if (aResult->iApps[i]->iWidgetBundleId)
+                    {
+                    ptrBuf.Append( BufToDesLC( *aResult->iApps[i]->iWidgetBundleId ) );
+                    CleanupStack::PopAndDestroy(); // BufToDesLC
+                    }
+                
+                ptrBuf.Append( KSConAppInfoSeparator );
                 
                 LOGGER_WRITE( "CSConPCConnSession::AppendListInstalledAppsResultsL() : set data" );
                 app->data->uid = new ( ELeave ) pcdata_t();
@@ -2330,7 +2330,7 @@
                 CleanupStack::PopAndDestroy(); // BufToDesLC
                 
-                // create uid: UID # Type # Size # Version # Vendor # Parent app. name #
+                // create uid: UID # Type # Size # Version # Vendor # Parent app. name # WidgetBundleId #
                 LOGGER_WRITE( "CSConPCConnSession::AppendListInstalledAppsResultsL() : Create Uid" );
                 